@@ -4,7 +4,7 @@ package JAAS::Factory;
 use strict;
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
-$VERSION = '0.01';
+$VERSION = '0.03';
 BEGIN {
     if($INC{"JAAS/Object/Services.pm"})
     { *DEBUG=sub () {JAAS::Object::Services->debug()}; }
@@ -27,7 +27,7 @@ sub new
 sub make
 {
     my($self, $name, @args)=@_;
-    DEBUG and warn "Making $name";
+    DEBUG and warn "********************* Making $name";
 
     my $c=$self->{config}->for($name);
     unless($c) {
@@ -48,6 +48,7 @@ sub make
     my $constructor=$self->find_ctor($package, $c->{ctor});
     unless($constructor) {
         $@="Can't find constructor for $package";
+        warn join "\n", map {"$_ = $INC{$_}"} sort keys %INC;
         return
     }
     DEBUG and warn "Constructor for $package is $constructor";
@@ -141,7 +142,8 @@ sub load_package
 
     # this next line might not be necessary
     delete $INC{$path};
-    DEBUG and warn "Can't load $path: $@\n";
+    # DEBUG and 
+        warn "Can't load $path: $@\n";
     return;
 }
 
@@ -437,7 +439,8 @@ pull your code out of new and exciting places.
 
 =head1 AUTHOR
 
-Philip Gwyn <gwynp@artware.qc.ca>
+Philip Gwyn <jaas at awale.qc.ca>, 
+Learry Gagn <mou-jaas at awale.qc.ca>.
 
 =cut
 
